0.0.30
Se actualiza función **color message**
0.0.31
Se actualiza función **footer_signature_html**
Se crea nueva funcion get_data_resources y get_data_cache (no se implementa por el momento), y se cambia el nombre de la funcion full_read_excel por set_resources
0.0.32
Se actualiza footer_signature_html
0.0.33
Se actualiza footer_signature_html nuevamente por diferencias en el color del equipo y espacios entre integrantes
0.0.34
Se agrega dependencia de libreria Sikuli
0.0.35
Se actualiza la función set_resources para que no sea necesario utilizar un resource de manera obligatoria, y en caso de no tenerlo que se genere uno vacio.
0.0.36
-
0.0.37
Se crea función set_data_cache para guardar datos en memoria y se complementa con la función get_data_cache.
0.0.38
Se actualiza función set_data_cache para que se pueda guardar cualquier valor en "value"
0.0.39
Se mofidica line 166, 99
0.0.40
Se actualiza función **footer_signature_html**cd 
0.0.41
Se actualiza parte de los mansajes de tipo print a logger
0.0.42
Se agrega import de andreani-qa-selenium y se corrige linea de logger
0.0.43
Se corrigen mas lineas de Selenium.logger